==> RPD-0.4.0.tar.gz: RPD-0.4.0/rpd/presence.py <==
# -*- coding: utf-8 -*-
# cython: language_level=3
# Copyright (c) 2021-present VincentRPS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE
"""Represents a Discord Presence"""

import time

from rpd.api.gateway import Gateway
from rpd.state import ConnectionState


class Presence:
    def __init__(self, status: str = "online", afk: bool = False):
        self.state = ConnectionState()
        self.status = status
        self.afk = afk

    async def add(self, name: str, type: int = 0):
        self.gate = Gateway(state=self.state)
        if not self.gate.ws:
            raise
        await self.gate.send(
            {
                "op": 3,
                "d": {
                    "since": time.time(),
                    "activites": [{"name": str(name), "type": int(type)}],
                    "status": self.status,
                    "afk": self.afk,
                },
            }
        )

    async def edit(self, name, type: int = 0):
        if not self.gate.ws:
            raise
        self.gate.send(
            {
                "op": 3,
                "d": {
                    "since": time.time(),
                    "activites": [{"name": str(name), "type": int(type)}],
                    "status": self.status,
                    "afk": self.afk,
                },
            }
        )

==> RPD-0.4.2.tar.gz: RPD-0.4.2/rpd/presence.py <==
# -*- coding: utf-8 -*-
# cython: language_level=3
# Copyright (c) 2021-present VincentRPS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE
"""Represents a Discord Presence"""

import time

from rpd.api.gateway import Gateway


class Presence:
    def __init__(self, state, status: str = "online", afk: bool = False):
        self.state = state
        self.gate = Gateway(state=self.state)
        self.status = status
        self.afk = afk

    async def add(self, name: str, type: int = 0):
        if not self.gate.ws:
            raise
        await self.gate.send(
            {
                "op": 3,
                "d": {
                    "since": time.time(),
                    "activites": [{"name": str(name), "type": int(type)}],
                    "status": self.status,
                    "afk": self.afk,
                },
            }
        )

    async def edit(self, name, type: int = 0):
        if not self.gate.ws:
            raise
        self.gate.send(
            {
                "op": 3,
                "d": {
                    "since": time.time(),
                    "activites": [{"name": str(name), "type": int(type)}],
                    "status": self.status,
                    "afk": self.afk,
                },
            }
        )
